/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __NEWSRC_H__
#define __NEWSRC_H__

#include "pan-object.h"

#define NEWSRC(x) ((Newsrc *)(x))

typedef struct
{
	/* parent class */
	PanObject object;

	/* private fields */
	GPtrArray * read;
	gchar * read_str;
	gulong group_low;
	gulong group_high;
}
Newsrc;


/**
***  PROTECTED
**/

void      newsrc_constructor      (Newsrc             * newsrc,
                                   const char         * read_str,
                                   gulong               group_low,
                                   gulong               group_high);

void      newsrc_destructor       (PanObject          * object);


/**
***  PUBLIC
**/

/**
***  Life Cycle
**/

Newsrc*   newsrc_new              (const char         * read_str,
                                   gulong               group_low,
                                   gulong               group_high);

void      newsrc_init             (Newsrc             * newsrc,
                                   const char         * read_str,
                                   gulong               group_low,
                                   gulong               group_high);

/**
***  Client functions
**/

/** returns previous state */
gboolean  newsrc_mark_article     (Newsrc             * newsrc,
                                   gulong               article_number,
				   gboolean             read);

void      newsrc_mark_all         (Newsrc             * newsrc,
                                   gboolean             read);

gboolean  newsrc_is_article_read  (const Newsrc       * newsrc,
                                   gulong               article_number);


/**
***  Compatability with other newsreaders
**/

void      newsrc_import           (Newsrc             * newsrc,
                                   gboolean           * setme_subscribed,
                                   const char         * import_string);

void      newsrc_export           (const Newsrc       * newsrc,
                                   const char         * group_name,
                                   gboolean             subscribed,
                                   GString            * appendme);

/**
***  Housekeeping
**/

void      newsrc_set_group_range  (Newsrc             * newsrc,
                                   gulong               group_low,
                                   gulong               group_high);

void      newsrc_get_read_str     (const Newsrc       * newsrc,
                                   GString            * appendme);


#endif /* __NEWSRC_H__ */
